import 'package:flutter/material.dart';
import 'package:transit_navigation_view/transit_navigation_view.dart';
import 'package:transit_navigation_view/utility.dart';

class SummaryViewContent extends StatelessWidget {
  final List<TransitData> listTransitData;

  SummaryViewContent({
    Key? key,
    required this.listTransitData,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: EdgeInsets.symmetric(vertical: 10, horizontal: 5.0),
      child: ListView.builder(
        itemCount: listTransitData.length,
        itemBuilder: (context, index) {
          final transitData = listTransitData[index];
          return _buildRouteSummaryCard(transitData, index);
        },
      ),
    );
  }

  Widget _buildRouteSummaryCard(TransitData transitData, int index) {
    bool showPassType = transitData.passDataList.any((passData) => passData.passType != null); 

    final titleWidget = Container(
      margin: const EdgeInsets.all(8),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
                        Text("経路${index + 1}", style: TextStyle(fontSize: 16, fontWeight: FontWeight.bold)),

          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text("${transitData.dptTime}発 - ${transitData.arvTime}着",
                  style:
                      TextStyle(fontSize: 20.0, fontWeight: FontWeight.bold)),
              _buildYasuHayaRakuIcons(transitData),
            ],
          ),
          SizedBox(height: 10),
          Container(
            padding: const EdgeInsets.symmetric(vertical: 0, horizontal: 10),
            child: Column(
              children: [
                Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    Text("運賃：" + intToPriceString(transitData.totalFee)),
                    const SizedBox(width: 20),
                    Text("乗換：" + (transitData.numOfTransit).toString() + "回"),
                    Container(),
                  ],
                ),
                const SizedBox(height: 10),
                showPassType ? _PassTypeIndicator(transitData: transitData) : Container(),
                // const SizedBox(height: 10),
                // _PassTypeIndicator(transitData: transitData),
              ],
            ),
          ),
        ],
      ),
    );
    return Builder(builder: (context) {
      return Card(
        shadowColor: null,
        color: Colors.grey[200],
        child: ListTile(
          // dense: true,
          // isThreeLine: true,
          trailing: const Icon(Icons.chevron_right),
          title: titleWidget,
          onTap: () {
            final controller = DefaultTabController.of(context);
            if (controller == null) {
              debugPrint("Failed to get tab controller");
              return;
            }
            controller.animateTo(index + 1);
          },
        ),
      );
    });
  }

  Widget _buildCircleCharacterIcon(String character,
      {Color? color = Colors.grey}) {
    return Container(
      width: 22,
      height: 22,
      decoration: BoxDecoration(
        color: color,
        shape: BoxShape.circle,
      ),
      child: Center(
        child: Text(
          character,
          style: const TextStyle(
            fontSize: 14,
            fontWeight: FontWeight.bold,
            color: Colors.white,
          ),
          textAlign: TextAlign.center,
        ),
      ),
    );
  }

  Widget _buildYasuHayaRakuIcons(TransitData transitData) {
    Widget yasuIconContainer = transitData.flagYasu ?? false
        ? _buildCircleCharacterIcon('安', color: Colors.lightBlue)
        : Container();
    Widget rakuIconContainer = transitData.flagRaku ?? false
        ? _buildCircleCharacterIcon('楽', color: Colors.amber)
        : Container();
    Widget hayaIconContainer = transitData.flagHaya ?? false
        ? _buildCircleCharacterIcon('早', color: Colors.red)
        : Container();

    return Row(
      mainAxisAlignment: MainAxisAlignment.start,
      mainAxisSize: MainAxisSize.min,
      children: [
        yasuIconContainer,
        rakuIconContainer,
        hayaIconContainer,
      ],
    );
  }
}

class _PassTypeIndicator extends StatelessWidget {
  final TransitData transitData;

  _PassTypeIndicator({required this.transitData});

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.start,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        const Text("経路： "),
        // SizedBox(width: 20),
        Expanded(child: _buildPassTypeIconList(transitData)),
      ],
    );
  }

  Widget _buildPassTypeIconList(TransitData transitData) {
    return Container(
      width: 150,
      height: 50,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        mainAxisSize: MainAxisSize.max,
        children: [
          Expanded(
            child: ListView.builder(
              itemCount: transitData.numOfTransit,
              scrollDirection: Axis.horizontal,
              itemBuilder: (context, index) {
                return _buildPassTypeIcon(transitData, index);
              },
            ),
          ),
        ],
      ),
    );
  }

  Widget _buildPassTypeIcon(TransitData transitData, int index) {
    if (transitData.passDataList.length <= index) {
      return Container();
    }

    final passType = transitData.passDataList[index].passType;
    final IconData iconData;
    final Color iconColor;
    final String text;
    if (passType == PassType.bus) {
      iconData = Icons.directions_bus;
      iconColor = Colors.red;
      text = "バス";
    } else if (passType == PassType.subway) {
      iconData = Icons.directions_transit;
      iconColor = Colors.amber;
      text = "電車";
    } else {
      iconData = Icons.directions_walk;
      iconColor = Colors.lightBlue;
      text = "徒歩";
    }

    return Row(
      children: [
        index == 0 ? Container() : Icon(Icons.arrow_right),
        Column(children: [
          Icon(
            iconData,
            color: iconColor,
          ),
          Text(text, style: TextStyle(fontSize: 12)),
        ]),
      ],
    );
  }
}
