import 'package:flutter/material.dart';
import 'package:timelines/timelines.dart';
import 'package:transit_navigation_view/summary_page.dart';
import 'package:transit_navigation_view/detail_page.dart';
import 'package:transit_navigation_view/transit_navigation_scaffold.dart';

enum PassType {
  bus,
  subway,
  walk,
}

class StationData {
  String timeString, stationString;

  StationData({
    this.timeString = '',
    this.stationString = '',
  });
}

class PassData {
  PassType? passType;
  String timeString, passString, feeString;

  PassData({
    this.passType,
    this.timeString = '',
    this.passString = '',
    this.feeString = '',
  });
}

class TransitData {
  String dptTime, arvTime, totalTime;
  String? walkTime, distance;
  int numOfTransit, totalFee;
  bool? flagRaku, flagHaya, flagYasu;
  List<StationData> stationDataList;
  List<PassData> passDataList;

  TransitData({
    this.dptTime = '',
    this.arvTime = '',
    this.numOfTransit = 0,
    this.totalFee = 0,
    this.totalTime = '',
    this.walkTime,
    this.distance,
    this.flagRaku,
    this.flagHaya,
    this.flagYasu,
    this.stationDataList = const [],
    this.passDataList = const [],
  });
}

class TransitNavigationView extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Timeline.tileBuilder(
      builder: TimelineTileBuilder.fromStyle(
        contentsAlign: ContentsAlign.alternating,
        contentsBuilder: (context, index) => Padding(
          padding: const EdgeInsets.all(24.0),
          child: Text('Timeline Event $index'),
        ),
        itemCount: 10,
      ),
    );
  }
}

class TransitNavigationSummaryView extends StatelessWidget {
  final List<TransitData> listTransitData;

  TransitNavigationSummaryView({
    Key? key,
    required this.listTransitData,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SummaryViewContent(listTransitData: listTransitData);
  }
}

class TransitNavigationDetailView extends StatelessWidget {
  final TransitData transitData;

  TransitNavigationDetailView({
    Key? key,
    required this.transitData,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return DetailViewContent(transitData: transitData);
  }
}

class TransitNavigationScaffold extends StatelessWidget {
  final List<TransitData> transitDataList;
  Widget? bottomWidget;

  TransitNavigationScaffold({
    Key? key,
    required this.transitDataList,
    this.bottomWidget,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return ScaffoldContent(transitDataList: transitDataList, bottomWidget: bottomWidget);
  }
}
